@@ -1,9 +1,11 @@
 import cv2
 import time
+from . import udp
 
 # 缓存20-50帧
 CAMERA_CACHE_LIST = []
-
+# 上次流地址
+RTSP_URL = None
 '''
 Date: 2024-02-18 15:22:12
 author: zjs
@@ -14,9 +16,14 @@ ACTIVE_CAMERA = None
 
 async def read(cam):
     print(cam)
-    global ACTIVE_CAMERA
+    global ACTIVE_CAMERA, RTSP_URL
+    if ACTIVE_CAMERA and ACTIVE_CAMERA.isOpened() and RTSP_URL == cam:
+        print('摄像头已经连接')
+        return
     cap = cv2.VideoCapture(cam)
+    RTSP_URL = cam
     ACTIVE_CAMERA = cap
+    print('摄像头已经连接')
     while True:
         if cap.isOpened():
             try:
@@ -39,6 +46,10 @@ async def read(cam):
                 time.sleep(2)
         else:
             print("拉取流地址失败")
+            udp.CAMERA_ID = {
+                "ip": None,
+                "port": None,
+            }
             return
 
 
