@@ -1,6 +1,6 @@
 
-from udp import CAMERA_INFO
-from util import checkPort
+from .udp import CAMERA_INFO
+from .util import checkPort
 
 '''
 Date: 2024-02-22 10:38:20
